cleanup
diff --git a/include/fuse.h b/include/fuse.h
index ca96084..ca3797f 100644
--- a/include/fuse.h
+++ b/include/fuse.h
@@ -34,6 +34,12 @@
 /** Handle for a FUSE filesystem */
 struct fuse;
 
+/** Structure containing a raw command */
+struct fuse_cmd;
+
+/** The lowlevel FUSE session */
+struct fuse_session;
+
 /** Function to add an entry in a readdir() operation
  *
  * @param buf the buffer passed to the readdir() operation
@@ -504,8 +510,8 @@
 /** Set function which can be used to get the current context */
 void fuse_set_getcontext_func(struct fuse_context *(*func)(void));
 
-/** Returns the lowlevel FUSE object */
-struct fuse_ll *fuse_get_lowlevel(struct fuse *f);
+/** Returns the lowlevel FUSE session */
+struct fuse_session *fuse_get_session(struct fuse *f);
 
 /* ----------------------------------------------------------- *
  * Compatibility stuff                                         *